# Changelog

All notable changes to this project will be documented in this file.

## [Unreleased]
### Added
- Changelog and contribution guidelines.

## [0.1.0] - 2025-08-28
### Added
- Initial release with environment setup helpers for OpenAI and Telegram.

